Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(163)

Unified Diff: src/heap/gc-tracer.h

Issue 849693004: Use more conservative average promotion ratio for initial heap size. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/heap/gc-tracer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap/gc-tracer.h
diff --git a/src/heap/gc-tracer.h b/src/heap/gc-tracer.h
index 528eb52c6455f073f8ed4139278ac4f2ef7462a1..07c175935d4fa27a2d325d61cf57e053894e7657 100644
--- a/src/heap/gc-tracer.h
+++ b/src/heap/gc-tracer.h
@@ -164,14 +164,14 @@ class GCTracer {
};
- class SurvivalEvent {
+ class PromotionEvent {
public:
// Default constructor leaves the event uninitialized.
- SurvivalEvent() {}
+ PromotionEvent() {}
- explicit SurvivalEvent(double survival_rate);
+ explicit PromotionEvent(double promotion_ratio);
- double survival_rate_;
+ double promotion_ratio_;
};
@@ -283,7 +283,7 @@ class GCTracer {
typedef RingBuffer<ContextDisposalEvent, kRingBufferMaxSize>
ContextDisposalEventBuffer;
- typedef RingBuffer<SurvivalEvent, kRingBufferMaxSize> SurvivalEventBuffer;
+ typedef RingBuffer<PromotionEvent, kRingBufferMaxSize> PromotionEventBuffer;
explicit GCTracer(Heap* heap);
@@ -299,7 +299,7 @@ class GCTracer {
void AddContextDisposalTime(double time);
- void AddSurvivalRate(double survival_rate);
+ void AddPromotionRatio(double promotion_ratio);
// Log an incremental marking step.
void AddIncrementalMarkingStep(double duration, intptr_t bytes);
@@ -387,10 +387,10 @@ class GCTracer {
// Returns 0 if no events have been recorded.
double ContextDisposalRateInMilliseconds() const;
// Computes the average survival rate based on the last recorded survival
// events.
// Returns 0 if no events have been recorded.
- double AverageSurvivalRate() const;
+ double AveragePromotionRatio() const;
// Returns true if at least one survival event was recorded.
bool SurvivalEventsRecorded() const;
@@ -451,8 +451,8 @@ class GCTracer {
// RingBuffer for context disposal events.
ContextDisposalEventBuffer context_disposal_events_;
- // RingBuffer for survival events.
- SurvivalEventBuffer survival_events_;
+ // RingBuffer for promotion events.
+ PromotionEventBuffer promotion_events_;
// Cumulative number of incremental marking steps since creation of tracer.
int cumulative_incremental_marking_steps_;
« no previous file with comments | « no previous file | src/heap/gc-tracer.cc » ('j') | no next file with comments »
@@ -387,10 +387,10 @@ class GCTracer {
// Returns 0 if no events have been recorded.
double ContextDisposalRateInMilliseconds() const;
- // Computes the average survival rate based on the last recorded survival
+ // Computes the average promotion ratio based on the last recorded promotion
// events.
// Returns 0 if no events have been recorded.

Powered by Google App Engine
This is Rietveld 408576698